pub enum Event<T: Config<I>, I: 'static = ()> {
Show 22 variants
Endowed {
account: T::AccountId,
free_balance: T::Balance,
},
DustLost {
account: T::AccountId,
amount: T::Balance,
},
Transfer {
from: T::AccountId,
to: T::AccountId,
amount: T::Balance,
},
BalanceSet {
who: T::AccountId,
free: T::Balance,
},
Reserved {
who: T::AccountId,
amount: T::Balance,
},
Unreserved {
who: T::AccountId,
amount: T::Balance,
},
ReserveRepatriated {
from: T::AccountId,
to: T::AccountId,
amount: T::Balance,
destination_status: BalanceStatus,
},
Deposit {
who: T::AccountId,
amount: T::Balance,
},
Withdraw {
who: T::AccountId,
amount: T::Balance,
},
Slashed {
who: T::AccountId,
amount: T::Balance,
},
Minted {
who: T::AccountId,
amount: T::Balance,
},
Burned {
who: T::AccountId,
amount: T::Balance,
},
Suspended {
who: T::AccountId,
amount: T::Balance,
},
Restored {
who: T::AccountId,
amount: T::Balance,
},
Upgraded {
who: T::AccountId,
},
Issued {
amount: T::Balance,
},
Rescinded {
amount: T::Balance,
},
Locked {
who: T::AccountId,
amount: T::Balance,
},
Unlocked {
who: T::AccountId,
amount: T::Balance,
},
Frozen {
who: T::AccountId,
amount: T::Balance,
},
Thawed {
who: T::AccountId,
amount: T::Balance,
},
TotalIssuanceForced {
old: T::Balance,
new: T::Balance,
},
// some variants omitted
}Expand description
The Event enum of this pallet
Variants
Endowed
An account was created with some free balance.
DustLost
An account was removed whose balance was non-zero but below ExistentialDeposit, resulting in an outright loss.
Transfer
Transfer succeeded.
BalanceSet
A balance was set by root.
Reserved
Some balance was reserved (moved from free to reserved).
Unreserved
Some balance was unreserved (moved from reserved to free).
ReserveRepatriated
Some balance was moved from the reserve of the first account to the second account. Final argument indicates the destination balance type.
Deposit
Some amount was deposited (e.g. for transaction fees).
Withdraw
Some amount was withdrawn from the account (e.g. for transaction fees).
Slashed
Some amount was removed from the account (e.g. for misbehavior).
Minted
Some amount was minted into an account.
Burned
Some amount was burned from an account.
Suspended
Some amount was suspended from an account (it can be restored later).
Restored
Some amount was restored into an account.
Upgraded
An account was upgraded.
Issued
Total issuance was increased by amount, creating a credit to be balanced.
Rescinded
Total issuance was decreased by amount, creating a debt to be balanced.
Locked
Some balance was locked.
Unlocked
Some balance was unlocked.
Frozen
Some balance was frozen.
Thawed
Some balance was thawed.
TotalIssuanceForced
The TotalIssuance was forcefully changed.